<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>亮度设置</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;背光和亮度设置：&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>背光</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation>亮度</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>要求在改变设置后确认</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="112"/>
        <source>Brightness settings changed</source>
        <translation>亮度设置已改变</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="113"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>需要确认。设置是否正确？</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;输出:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Increase brightness.</source>
        <translation>提高亮度。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Decrease brightness.</source>
        <translation>降低亮度。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>设置亮度从 1 到 100。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Reset gamma to default value.</source>
        <translation>重置伽马为默认值。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="112"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation>%1: 不能同时使用提高/降低和设置</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation>%1: 不能同时使用提高和降低选项</translation>
    </message>
</context>
</TS>
